Struct google_deploymentmanager2::ResourceUpdate [−][src]
pub struct ResourceUpdate {
pub access_control: Option<ResourceAccessControl>,
pub final_properties: Option<String>,
pub warnings: Option<Vec<ResourceUpdateWarnings>>,
pub manifest: Option<String>,
pub state: Option<String>,
pub intent: Option<String>,
pub error: Option<ResourceUpdateError>,
pub properties: Option<String>,
}This type is not used in any activity, and only used as part of another schema.
Fields
access_control: Option<ResourceAccessControl>
The Access Control Policy to set on this resource after updating the resource itself.
final_properties: Option<String>
Output only. The expanded properties of the resource with reference values expanded. Returned as serialized YAML.
warnings: Option<Vec<ResourceUpdateWarnings>>
Output only. If warning messages are generated during processing of this resource, this field will be populated.
manifest: Option<String>
Output only. URL of the manifest representing the update configuration of this resource.
state: Option<String>
Output only. The state of the resource.
intent: Option<String>
Output only. The intent of the resource: PREVIEW, UPDATE, or CANCEL.
error: Option<ResourceUpdateError>
Output only. If errors are generated during update of the resource, this field will be populated.
properties: Option<String>
Output only. The set of updated properties for this resource, before references are expanded. Returned as serialized YAML.