Struct google_deploymentmanager2::ResourceUpdateErrorErrors [−][src]
pub struct ResourceUpdateErrorErrors {
pub message: Option<String>,
pub code: Option<String>,
pub location: Option<String>,
}[Output Only] The array of errors encountered while processing this operation.
This type is not used in any activity, and only used as part of another schema.
Fields
message: Option<String>
[Output Only] An optional, human-readable error message.
code: Option<String>
[Output Only] The error type identifier for this error.
location: Option<String>
[Output Only] Indicates the field in the request that caused the error. This property is optional.