Struct google_deploymentmanager2::ResourceUpdateError [−][src]
pub struct ResourceUpdateError {
pub errors: Option<Vec<ResourceUpdateErrorErrors>>,
}Output only. If errors are generated during update of the resource, this field will be populated.
This type is not used in any activity, and only used as part of another schema.
Fields
errors: Option<Vec<ResourceUpdateErrorErrors>>
[Output Only] The array of errors encountered while processing this operation.